@@ -75,6 +75,8 @@
 
 static PCONF_HTBL_ENTRY hash_table[300] = { NULL };
 
+static size_t longest_set_count = 0;
+
 static struct tagConfDefValues {
 	const char		*setting_name;
 	enum setting_type	 type;
@@ -295,7 +297,7 @@ output_value_for_specific_setting(const char *setting)
 	print_and_free("/set: no such setting", NULL);
 }
 
-static void
+void
 output_values_for_all_settings(void)
 {
 	PRINTTEXT_CONTEXT	ctx;
@@ -308,6 +310,44 @@ output_values_for_all_settings(void)
 	}
 }
 
+void
+output_values_for_all_settings_v2(void)
+{
+	char		*cp[2];
+	char		 fmt[2][100];
+	const int	 i = static_cast<int>(longest_set_count);
+	int		 ret[2];
+
+	cp[0] = &fmt[0][0];
+	cp[1] = &fmt[1][0];
+
+	ret[0] = snprintf(cp[0], sizeof(fmt[0]), "%%%ds %%7s %%s", i);
+	ret[1] = snprintf(cp[1], sizeof(fmt[1]), "%%%ds %%7s %%s", i);
+
+	if (ret[0] < 0 || static_cast<size_t>(ret[0]) >= sizeof(fmt[0]) ||
+	    ret[1] < 0 || static_cast<size_t>(ret[1]) >= sizeof(fmt[1])) {
+		printtext_print("err", "snprintf() error");
+		return;
+	}
+
+	printtext_print("none", cp[0], "Name", "Type", "Value");
+	printtext_print("none", cp[0], "----", "----", "-----");
+
+	FOREACH_CDV() {
+		const char	*name = cdv_p->setting_name;
+		const char	*type = get_setting_type(cdv_p);
+		std::string	 value("");
+
+		if (!strings_match(name, "ftp_pass") &&
+		    !strings_match(name, "sasl_password"))
+			value.assign(Config(name));
+		else
+			value.assign(xstrnlen(Config(name), 20), '*');
+
+		printtext_print("none", cp[1], name, type, value.c_str());
+	}
+}
+
 static void
 set_value_for_setting_ok_hook(const char *setting, const char *value)
 {
@@ -404,19 +444,6 @@ write_config_header(FILE *fp)
 
 /* -------------------------------------------------- */
 
-static void
-add_name(PTEXTBUF matches, const char *name)
-{
-	if (textBuf_size(matches) == 0) {
-		if ((errno = textBuf_ins_next(matches, NULL, name, -1)) != 0)
-			err_sys("%s: textBuf_ins_next", __func__);
-	} else {
-		if ((errno = textBuf_ins_next(matches, textBuf_tail(matches),
-		    name, -1)) != 0)
-			err_sys("%s: textBuf_ins_next", __func__);
-	}
-}
-
 PTEXTBUF
 get_list_of_matching_settings(const char *search_var)
 {
@@ -424,8 +451,10 @@ get_list_of_matching_settings(const char *search_var)
 	const size_t	varlen = strlen(search_var);
 
 	FOREACH_CDV() {
-		if (!strncmp(search_var, cdv_p->setting_name, varlen))
-			add_name(matches, cdv_p->setting_name);
+		if (!strncmp(search_var, cdv_p->setting_name, varlen)) {
+			textBuf_emplace_back(__func__, matches,
+			    cdv_p->setting_name, 0);
+		}
 	}
 
 	if (textBuf_size(matches) == 0) {
@@ -439,9 +468,15 @@ get_list_of_matching_settings(const char *search_var)
 void
 config_init(void)
 {
+	size_t len = 0;
+
 	ENTRY_FOREACH() {
 		*entry_p = NULL;
 	}
+	FOREACH_CDV() {
+		if ((len = strlen(cdv_p->setting_name)) > longest_set_count)
+			longest_set_count = len;
+	}
 }
 
 void
@@ -721,7 +756,7 @@ get_sasl(const char *what, char *buf, size_t bufsize)
 		return NULL;
 	}
 
-	flags = static_cast<Stringprep_profile_flags>(0);
+	flags = static_cast<Stringprep_profile_flags>(0); // NOLINT
 
 	if ((ret = stringprep_profile(str, &sp_out, "SASLprep", flags)) ==
 	    STRINGPREP_OK && sw_strcpy(buf, sp_out, bufsize) == 0) {
@@ -787,7 +822,7 @@ cmd_set(const char *data)
 	const char	*setting, *value;
 
 	if (strings_match(data, "")) {
-		output_values_for_all_settings();
+		output_values_for_all_settings_v2();
 		return;
 	}
 
