@@ -88,7 +88,7 @@
 /* Things with external linkage
    ============================ */
 
-chararray_t	g_swircVersion	= "v3.5.4";
+chararray_t	g_swircVersion	= "v3.5.5";
 chararray_t	g_swircYear	= "2012-2025";
 chararray_t	g_swircAuthor	= "Markus Uhlin";
 chararray_t	g_swircWebAddr	= "https://www.nifty-networks.net/swirc/";
@@ -101,6 +101,8 @@ long int	 g_pid = -1;
 int	 g_stderr_fd = -1;
 int	 g_stdout_fd = -1;
 
+SSCANF_FN xsscanf = sscanf;
+
 SETLOCALE_FN	 xsetlocale = nullptr;
 char		 g_locale[200] = { '\0' };
 
@@ -662,6 +664,9 @@ main(int argc, char *argv[])
 
 	malloc_options = const_cast<char *>("S");
 #endif
+#ifdef HAVE_BCI
+	xsscanf = sscanf_s;
+#endif
 
 	if ((cp = strrchr(argv[0], SLASH_CHAR)) == nullptr)
 		g_progname = argv[0];
@@ -875,6 +880,12 @@ redir_stderr(void)
 {
 	const bool is_valid_fd = (g_stderr_fd != -1);
 
+/*
+ * The POSIX names are needed for portability reasons
+ */
+#if WIN32
+#pragma warning(disable: 4996)
+#endif
 	if (is_valid_fd)
 		err_log(EBUSY, "%s: valid file descriptor", __func__);
 	else if (!isValid(g_dev_null))
@@ -885,6 +896,12 @@ redir_stderr(void)
 		err_sys("%s: dup2() error", __func__);
 	else
 		return;
+/*
+ * Reset warning behavior to its default value
+ */
+#if WIN32
+#pragma warning(default: 4996)
+#endif
 }
 
 void
@@ -892,6 +909,12 @@ restore_stderr(void)
 {
 	const bool is_valid_fd = (g_stderr_fd != -1);
 
+/*
+ * The POSIX names are needed for portability reasons
+ */
+#if WIN32
+#pragma warning(disable: 4996)
+#endif
 	if (!is_valid_fd)
 		err_log(EBADF, "%s", __func__);
 	else if (dup2(g_stderr_fd, fileno(stderr)) == -1)
@@ -900,4 +923,10 @@ restore_stderr(void)
 		err_log(errno, "%s: close() error", __func__);
 	else
 		g_stderr_fd = -1;
+/*
+ * Reset warning behavior to its default value
+ */
+#if WIN32
+#pragma warning(default: 4996)
+#endif
 }
