@@ -1,5 +1,5 @@
 /* Prints and handles text
-   Copyright (C) 2012-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -350,7 +350,7 @@ convert_wc(wchar_t wc, size_t &bytes_out)
 	    size, wc, &ps)) != 0 ||
 	    bytes_written == g_conversion_failed ||
 	    bytes_written > size) {
-		if (wc != L'\0')
+		if (wc != L'\0' && errno != 0)
 			err_log(errno, "printtext: %s: wcrtomb_s", __func__);
 		*mbs = '\0';
 		bytes_out = 0;
@@ -702,7 +702,7 @@ new_row(WINDOW *win, int *insert_count, int *rep_count)
 	*insert_count = 0;
 
 	if (isValid(rep_count))
-		(*rep_count) ++;
+		(*rep_count)++; // NOLINT: false positive
 }
 
 /**
@@ -1545,8 +1545,23 @@ printtext_puts(WINDOW *pwin, CSTRING buf, int indent, int max_lines,
 				if ((diff = (wcp - wc_bufp)) > ARSZ - 1)
 					diff = ARSZ - 1;
 				sw_assert(diff > 0);
+#if defined(UNIX)
 				(void) wcsncpy(str, wc_bufp, diff);
 				str[diff] = L'\0';
+#elif defined(WIN32)
+				switch (wcsncpy_s(str, ARSZ, wc_bufp, diff)) {
+				case 0:
+					/* copying ok */
+					break;
+				case STRUNCATE:
+					err_log(0, "%s: wcsncpy_s: truncated",
+					    __func__);
+					break;
+				default:
+					sw_assert_not_reached();
+					break;
+				}
+#endif
 				if ((diff = xwcswidth(wcspbrk(str,
 				    L"\035\002\003\017\026\037") ?
 				    squeeze_text_deco_wide(str) : str, 2)) < 0)
@@ -1610,26 +1625,6 @@ vprinttext_mutex_init_doit()
 #endif
 }
 
-static void
-remove_head_from_buffer(PTEXTBUF buf)
-{
-	if ((errno = textBuf_remove(buf, textBuf_head(buf))) != 0)
-		err_sys("%s: %s: textBuf_remove", __FILE__, __func__);
-}
-
-static void
-add_to_buffer(PTEXTBUF buf, CSTRING text, const int indent)
-{
-	if (textBuf_size(buf) == 0) {
-		if ((errno = textBuf_ins_next(buf, nullptr, text, indent)) != 0)
-			err_sys("%s: %s: textBuf_ins_next", __FILE__, __func__);
-	} else {
-		if ((errno = textBuf_ins_next(buf, textBuf_tail(buf), text,
-		    indent)) != 0)
-			err_sys("%s: %s: textBuf_ins_next", __FILE__, __func__);
-	}
-}
-
 /**
  * Variable argument list version of Swirc messenger
  *
@@ -1655,8 +1650,10 @@ vprinttext(PPRINTTEXT_CONTEXT ctx, CSTRING fmt, va_list ap)
 	free(fmt_copy);
 
 	if (tbszp1 > config_integer(&intctx)) /* Buffer full... */
-		remove_head_from_buffer(ctx->window->buf);
-	add_to_buffer(ctx->window->buf, pout.text, pout.indent);
+		textBuf_pop_head(__func__, ctx->window->buf);
+
+	textBuf_emplace_back(__func__, ctx->window->buf, pout.text,
+	    pout.indent);
 
 	const bool shouldOutData = !(ctx->window->scroll_mode);
 
